# ---
# jupyter:
#   jupytext:
#     text_representation:
#       extension: .py
#       format_name: percent
#       format_version: '1.3'
#       jupytext_version: 1.16.6
# ---

# %% [markdown]
# # Segmentation Test Cases

# %% [markdown]
# To facilitate testing, we have provided a suite of canonical
# examples that cover the basic, simple scenarios that can occur in segmentation
# and tracking. Here we describe them and show visualizations of each case.
#
# Matchers should test all the segmentation cases. Metrics should test all the
# tracking cases. The examples are generated by functions in the
# `tests/examples/` directory.

# %% nbsphinx="hidden"
import sys

sys.path.append("../../../tests")

# %%
import matplotlib.pyplot as plt
import numpy as np
from matplotlib.colors import ListedColormap
from matplotlib.patches import Patch

import examples.segs as ex_segs

# %% [markdown]
#
# Each example that is illustrated here in 2D is also implemented in 3d.


# %% nbsphinx="hidden"
def plot_pair(gt, pred, title):
    max_label = np.max([gt, pred])
    colors = ["black", "red", "blue", "green", "yellow"]
    colormap = ListedColormap(colors)
    fig, ax = plt.subplots(1, 2, figsize=(6, 4))
    ax[0].imshow(gt, cmap=colormap, vmax=5)
    ax[0].set_title("Ground Truth")
    ax[0].set_axis_off()
    ax[1].imshow(pred, cmap=colormap, vmax=5)
    ax[1].set_title("Predicted")

    handles = [Patch(color=colors[i]) for i in range(1, max_label + 1)]
    labels = [str(i) for i in range(1, max_label + 1)]
    ax[1].legend(handles=handles, labels=labels, title="Label IDs", loc="upper right")
    fig.suptitle(title, y=0.9)
    fig.tight_layout()


# %%
plot_pair(*ex_segs.good_segmentation_2d(), "Good Segmentation")

# %%
plot_pair(*ex_segs.false_positive_segmentation_2d(), "False Positive")

# %%
plot_pair(*ex_segs.false_negative_segmentation_2d(), "False Negative")

# %%
plot_pair(*ex_segs.oversegmentation_2d(), "Oversegmentation")

# %%
plot_pair(*ex_segs.undersegmentation_2d(), "Undersegmentation")

# %%
plot_pair(*ex_segs.no_overlap_2d(), "No Overlap")

# %%
plot_pair(*ex_segs.multicell_2d(), "Multiple cells")
